@@ -1,5 +1,5 @@
 
-# $Id: DE.pm,v 2.102 2010-03-31 03:37:34 Martin Exp $
+# $Id: DE.pm,v 2.103 2013-03-03 15:03:57 Martin Exp $
 
 =head1 NAME
 
@@ -32,7 +32,7 @@ use warnings;
 use Carp;
 use base 'WWW::Search::Ebay';
 our
-$VERSION = do { my @r = (q$Revision: 2.102 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
+$VERSION = do { my @r = (q$Revision: 2.103 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
 
 sub _native_setup_search
   {
@@ -40,10 +40,10 @@ sub _native_setup_search
   $rhOptsArg ||= {};
   unless (ref($rhOptsArg) eq 'HASH')
     {
-    carp " --- second argument to _native_setup_search should be hashref, not arrayref";
+    carp " --- second argument to _native_setup_search should be hashref";
     return undef;
     } # unless
-  $rhOptsArg->{search_host} = 'http://search.ebay.de';
+  $self->{search_host} = 'http://www.ebay.de';
   return $self->SUPER::_native_setup_search($native_query, $rhOptsArg);
   } # _native_setup_search
 
@@ -60,7 +60,7 @@ sub _result_count_element_specs_NOT_NEEDED
 
 sub _result_count_pattern
   {
-  return qr'(\d+)\s+(Artikel|Ergebnisse)\s+gefunden ';
+  return qr'(\d+)\s+(Artikel|Ergebnisse)\s+gefunden 'i;
   } # _result_count_pattern
 
 sub _next_text
@@ -101,7 +101,7 @@ sub _columns
   {
   my $self = shift;
   # This is for DE:
-  return qw( seller paypal bids price shipping enddate );
+  return qw( paypal bids price shipping enddate );
   } # _columns
 
 sub _process_date_abbrevs
